@@ -1,3 +1,213 @@
+
+#' Vertex connectivity
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `vertex.disjoint.paths()` was renamed to `vertex_disjoint_paths()` to create a more
+#' consistent API.
+#' @inheritParams vertex_disjoint_paths
+#' @keywords internal
+#' @export
+vertex.disjoint.paths <- function(graph, source = NULL, target = NULL) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "vertex.disjoint.paths()", "vertex_disjoint_paths()")
+  vertex_disjoint_paths(graph = graph, source = source, target = target)
+} # nocov end
+
+#' Vertex connectivity
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `vertex.connectivity()` was renamed to `vertex_connectivity()` to create a more
+#' consistent API.
+#' @inheritParams vertex_connectivity
+#' @keywords internal
+#' @export
+vertex.connectivity <- function(graph, source = NULL, target = NULL, checks = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "vertex.connectivity()", "vertex_connectivity()")
+  vertex_connectivity(graph = graph, source = source, target = target, checks = checks)
+} # nocov end
+
+#' List all minimum \((s,t)\)-cuts of a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `stMincuts()` was renamed to `st_min_cuts()` to create a more
+#' consistent API.
+#' @inheritParams st_min_cuts
+#' @keywords internal
+#' @export
+stMincuts <- function(graph, source, target, capacity = NULL) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "stMincuts()", "st_min_cuts()")
+  st_min_cuts(graph = graph, source = source, target = target, capacity = capacity)
+} # nocov end
+
+#' List all (s,t)-cuts of a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `stCuts()` was renamed to `st_cuts()` to create a more
+#' consistent API.
+#' @inheritParams st_cuts
+#' @keywords internal
+#' @export
+stCuts <- function(graph, source, target) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "stCuts()", "st_cuts()")
+  st_cuts(graph = graph, source = source, target = target)
+} # nocov end
+
+#' Minimum size vertex separators
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `minimum.size.separators()` was renamed to `min_separators()` to create a more
+#' consistent API.
+#' @inheritParams min_separators
+#' @keywords internal
+#' @export
+minimum.size.separators <- function(graph) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "minimum.size.separators()", "min_separators()")
+  min_separators(graph = graph)
+} # nocov end
+
+#' Minimum size vertex separators
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `minimal.st.separators()` was renamed to `min_st_separators()` to create a more
+#' consistent API.
+#' @inheritParams min_st_separators
+#' @keywords internal
+#' @export
+minimal.st.separators <- function(graph) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "minimal.st.separators()", "min_st_separators()")
+  min_st_separators(graph = graph)
+} # nocov end
+
+#' Vertex separators
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `is.separator()` was renamed to `is_separator()` to create a more
+#' consistent API.
+#' @inheritParams is_separator
+#' @keywords internal
+#' @export
+is.separator <- function(graph, candidate) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "is.separator()", "is_separator()")
+  is_separator(graph = graph, candidate = candidate)
+} # nocov end
+
+#' Minimal vertex separators
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `is.minimal.separator()` was renamed to `is_min_separator()` to create a more
+#' consistent API.
+#' @inheritParams is_min_separator
+#' @keywords internal
+#' @export
+is.minimal.separator <- function(graph, candidate) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "is.minimal.separator()", "is_min_separator()")
+  is_min_separator(graph = graph, candidate = candidate)
+} # nocov end
+
+#' Minimum cut in a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `graph.mincut()` was renamed to `min_cut()` to create a more
+#' consistent API.
+#' @inheritParams min_cut
+#' @keywords internal
+#' @export
+graph.mincut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.only = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "graph.mincut()", "min_cut()")
+  min_cut(graph = graph, source = source, target = target, capacity = capacity, value.only = value.only)
+} # nocov end
+
+#' Maximum flow in a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `graph.maxflow()` was renamed to `max_flow()` to create a more
+#' consistent API.
+#' @inheritParams max_flow
+#' @keywords internal
+#' @export
+graph.maxflow <- function(graph, source, target, capacity = NULL) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "graph.maxflow()", "max_flow()")
+  max_flow(graph = graph, source = source, target = target, capacity = capacity)
+} # nocov end
+
+#' Edge connectivity
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `graph.adhesion()` was renamed to `adhesion()` to create a more
+#' consistent API.
+#' @inheritParams adhesion
+#' @keywords internal
+#' @export
+graph.adhesion <- function(graph, checks = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "graph.adhesion()", "adhesion()")
+  adhesion(graph = graph, checks = checks)
+} # nocov end
+
+#' Edge connectivity
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `edge.disjoint.paths()` was renamed to `edge_connectivity()` to create a more
+#' consistent API.
+#' @inheritParams edge_connectivity
+#' @keywords internal
+#' @export
+edge.disjoint.paths <- function(graph, source = NULL, target = NULL, checks = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "edge.disjoint.paths()", "edge_connectivity()")
+  edge_connectivity(graph = graph, source = source, target = target, checks = checks)
+} # nocov end
+
+#' Edge connectivity
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `edge.connectivity()` was renamed to `edge_connectivity()` to create a more
+#' consistent API.
+#' @inheritParams edge_connectivity
+#' @keywords internal
+#' @export
+edge.connectivity <- function(graph, source = NULL, target = NULL, checks = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "edge.connectivity()", "edge_connectivity()")
+  edge_connectivity(graph = graph, source = source, target = target, checks = checks)
+} # nocov end
+
+#' Dominator tree
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `dominator.tree()` was renamed to `dominator_tree()` to create a more
+#' consistent API.
+#' @inheritParams dominator_tree
+#' @keywords internal
+#' @export
+dominator.tree <- function(graph, root, mode = c("out", "in", "all", "total")) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "dominator.tree()", "dominator_tree()")
+  dominator_tree(graph = graph, root = root, mode = mode)
+} # nocov end
 #   IGraph R package
 #   Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
 #   334 Harvard street, Cambridge, MA 02139 USA
@@ -42,7 +252,6 @@
 #' For undirected graphs the Stoer-Wagner algorithm (see reference below) is
 #' used to calculate the minimum cut.
 #'
-#' @aliases graph.mincut
 #' @param graph The input graph.
 #' @param source The id of the source vertex.
 #' @param target The id of the target vertex (sometimes also called sink).
@@ -64,9 +273,6 @@
 #'     after the cut edges are removed. Note that these vertices might be
 #'     actually in different components (after the cut edges are removed), as
 #'     the graph may fall apart into more than two components.}
-#' @seealso [max_flow()] for the related maximum flow
-#'   problem, [distances()], [edge_connectivity()],
-#'   [vertex_connectivity()]
 #' @references M. Stoer and F. Wagner: A simple min-cut algorithm,
 #' *Journal of the ACM*, 44 585-591, 1997.
 #' @examples
@@ -80,9 +286,7 @@
 #' @family flow
 #' @export
 min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.only = TRUE) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
   if (is.null(capacity)) {
     if ("capacity" %in% edge_attr_names(graph)) {
       capacity <- E(graph)$capacity
@@ -123,14 +327,14 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
     if (value.only) {
       res <- .Call(
         R_igraph_st_mincut_value, graph,
-        as.igraph.vs(graph, source) - 1,
-        as.igraph.vs(graph, target) - 1, capacity
+        as_igraph_vs(graph, source) - 1,
+        as_igraph_vs(graph, target) - 1, capacity
       )
     } else {
       res <- .Call(
         R_igraph_st_mincut, graph,
-        as.igraph.vs(graph, source) - 1,
-        as.igraph.vs(graph, target) - 1, capacity
+        as_igraph_vs(graph, source) - 1,
+        as_igraph_vs(graph, target) - 1, capacity
       )
       # No need to add +1 here; R_igraph_st_mincut() is autogenerated and
       # adds +1 already
@@ -153,12 +357,16 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
 #' called group cohesion.
 #'
 #' The vertex connectivity of two vertices (`source` and `target`) in
-#' a directed graph is the minimum number of vertices needed to remove from the
-#' graph to eliminate all (directed) paths from `source` to `target`.
+#' a graph is the minimum number of vertices that must be deleted to
+#' eliminate all (directed) paths from `source` to `target`.
 #' `vertex_connectivity()` calculates this quantity if both the
 #' `source` and `target` arguments are given and they're not
 #' `NULL`.
 #'
+#' The vertex connectivity of a pair is the same as the number
+#' of different (i.e. node-independent) paths from source to
+#' target, assuming no direct edges between them.
+#'
 #' The vertex connectivity of a graph is the minimum vertex connectivity of all
 #' (ordered) pairs of vertices in the graph. In other words this is the minimum
 #' number of vertices needed to remove to make the graph not strongly
@@ -182,8 +390,7 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
 #' precisely `vertex_connectivity()` is the most general, the other two are
 #' included only for the ease of using more descriptive function names.
 #'
-#' @aliases vertex.connectivity vertex.disjoint.paths cohesion vertex_connectivity
-#'   vertex_disjoint_paths graph.cohesion
+#' @aliases cohesion
 #' @param graph,x The input graph.
 #' @param source The id of the source vertex, for `vertex_connectivity()` it
 #'   can be `NULL`, see details below.
@@ -199,8 +406,6 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
 #' @param ... Ignored.
 #' @return A scalar real value.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
-#' @seealso [max_flow()], [edge_connectivity()],
-#' [edge_disjoint_paths()], [adhesion()]
 #' @references White, Douglas R and Frank Harary 2001. The Cohesiveness of
 #' Blocks In Social Networks: Node Connectivity and Conditional Density.
 #' *Sociological Methodology* 31 (1) : 305-359.
@@ -209,9 +414,9 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
 #' @keywords graphs
 #' @examples
 #'
-#' g <- barabasi.game(100, m = 1)
+#' g <- sample_pa(100, m = 1)
 #' g <- delete_edges(g, E(g)[100 %--% 1])
-#' g2 <- barabasi.game(100, m = 5)
+#' g2 <- sample_pa(100, m = 5)
 #' g2 <- delete_edges(g2, E(g2)[100 %--% 1])
 #' vertex_connectivity(g, 100, 1)
 #' vertex_connectivity(g2, 100, 1)
@@ -223,9 +428,7 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
 #' cohesion(g)
 #'
 vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TRUE) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   if (length(source) == 0) {
     source <- NULL
@@ -240,8 +443,8 @@ vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TR
   } else if (!is.null(source) && !is.null(target)) {
     on.exit(.Call(R_igraph_finalizer))
     .Call(
-      R_igraph_st_vertex_connectivity, graph, as.igraph.vs(graph, source) - 1,
-      as.igraph.vs(graph, target) - 1
+      R_igraph_st_vertex_connectivity, graph, as_igraph_vs(graph, source) - 1,
+      as_igraph_vs(graph, target) - 1
     )
   } else {
     stop("either give both source and target or neither")
@@ -255,6 +458,7 @@ vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TR
 #' The edge connectivity of a graph or two vertices, this is recently also
 #' called group adhesion.
 #'
+#' @section `edge_connectivity()` Edge connectivity:
 #' The edge connectivity of a pair of vertices (`source` and
 #' `target`) is the minimum number of edges needed to remove to eliminate
 #' all (directed) paths from `source` to `target`.
@@ -266,20 +470,34 @@ vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TR
 #' calculates this quantity if neither the `source` nor the `target`
 #' arguments are given (i.e. they are both `NULL`).
 #'
+#' @section `edge_disjoint_paths()` The maximum number of edge-disjoint paths between two vertices:
+#' A set of paths between two vertices is called edge-disjoint if they do not
+#' share any edges. The maximum number of edge-disjoint paths are calculated
+#' by this function using maximum flow techniques. Directed paths are
+#' considered in directed graphs.
+#'
+#'
 #' A set of edge disjoint paths between two vertices is a set of paths between
 #' them containing no common edges. The maximum number of edge disjoint paths
 #' between two vertices is the same as their edge connectivity.
 #'
+#' When there are no direct edges between the source and the target, the number
+#' of vertex-disjoint paths is the same as the vertex connectivity of
+#' the two vertices. When some edges are present, each one of them
+#' contributes one extra path.
+#'
+#' @section `adhesion()` Adhesion of a graph:
 #' The adhesion of a graph is the minimum number of edges needed to remove to
 #' obtain a graph which is not strongly connected. This is the same as the edge
 #' connectivity of the graph.
 #'
+#' @section All three functions:
 #' The three functions documented on this page calculate similar properties,
 #' more precisely the most general is `edge_connectivity()`, the others are
 #' included only for having more descriptive function names.
 #'
-#' @aliases edge.connectivity edge_disjoint_paths graph.adhesion adhesion
-#'   edge_connectivity edge.disjoint.paths
+#'
+
 #' @param graph The input graph.
 #' @param source The id of the source vertex, for `edge_connectivity()` it
 #'   can be `NULL`, see details below.
@@ -294,8 +512,6 @@ vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TR
 #'   thanks Peter.
 #' @return A scalar real value.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
-#' @seealso [max_flow()], [vertex_connectivity()],
-#' [vertex_disjoint_paths()], [cohesion()]
 #' @references Douglas R. White and Frank Harary: The cohesiveness of blocks in
 #' social networks: node connectivity and conditional density, TODO: citation
 #' @family flow
@@ -303,8 +519,8 @@ vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TR
 #' @keywords graphs
 #' @examples
 #'
-#' g <- barabasi.game(100, m = 1)
-#' g2 <- barabasi.game(100, m = 5)
+#' g <- sample_pa(100, m = 1)
+#' g2 <- sample_pa(100, m = 5)
 #' edge_connectivity(g, 100, 1)
 #' edge_connectivity(g2, 100, 1)
 #' edge_disjoint_paths(g2, 100, 1)
@@ -315,9 +531,7 @@ vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TR
 #' adhesion(g)
 #'
 edge_connectivity <- function(graph, source = NULL, target = NULL, checks = TRUE) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   if (length(source) == 0) {
     source <- NULL
@@ -333,19 +547,17 @@ edge_connectivity <- function(graph, source = NULL, target = NULL, checks = TRUE
     on.exit(.Call(R_igraph_finalizer))
     .Call(
       R_igraph_st_edge_connectivity, graph,
-      as.igraph.vs(graph, source) - 1, as.igraph.vs(graph, target) - 1
+      as_igraph_vs(graph, source) - 1, as_igraph_vs(graph, target) - 1
     )
   } else {
     stop("either give both source and target or neither")
   }
 }
 
-#' @family flow
+#' @rdname edge_connectivity
 #' @export
 edge_disjoint_paths <- function(graph, source, target) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   if (length(source) == 0) {
     source <- NULL
@@ -357,16 +569,14 @@ edge_disjoint_paths <- function(graph, source, target) {
   on.exit(.Call(R_igraph_finalizer))
   .Call(
     R_igraph_edge_disjoint_paths, graph,
-    as.igraph.vs(graph, source) - 1, as.igraph.vs(graph, target) - 1
+    as_igraph_vs(graph, source) - 1, as_igraph_vs(graph, target) - 1
   )
 }
 
-#' @family flow
+#' @rdname vertex_connectivity
 #' @export
 vertex_disjoint_paths <- function(graph, source = NULL, target = NULL) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   if (length(source) == 0) {
     source <- NULL
@@ -377,17 +587,15 @@ vertex_disjoint_paths <- function(graph, source = NULL, target = NULL) {
 
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_vertex_disjoint_paths, graph, as.igraph.vs(graph, source) - 1,
-    as.igraph.vs(graph, target) - 1
+    R_igraph_vertex_disjoint_paths, graph, as_igraph_vs(graph, source) - 1,
+    as_igraph_vs(graph, target) - 1
   )
 }
 
-#' @family flow
+#' @rdname edge_connectivity
 #' @export
 adhesion <- function(graph, checks = TRUE) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   on.exit(.Call(R_igraph_finalizer))
   .Call(R_igraph_adhesion, graph, as.logical(checks))
@@ -395,12 +603,9 @@ adhesion <- function(graph, checks = TRUE) {
 
 #' @rdname vertex_connectivity
 #' @method cohesion igraph
-#' @family flow
 #' @export
 cohesion.igraph <- function(x, checks = TRUE, ...) {
-  if (!is_igraph(x)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(x)
 
   on.exit(.Call(R_igraph_finalizer))
   .Call(R_igraph_cohesion, x, as.logical(checks))
@@ -415,7 +620,6 @@ cohesion.igraph <- function(x, checks = TRUE, ...) {
 #' removing these edges from \eqn{G} there is no directed path from \eqn{s} to
 #' \eqn{t}.
 #'
-#' @aliases stCuts st_cuts
 #' @param graph The input graph. It must be directed.
 #' @param source The source vertex.
 #' @param target The target vertex.
@@ -427,7 +631,6 @@ cohesion.igraph <- function(x, checks = TRUE, ...) {
 #'   and its complementer \eqn{V-X}, generates the cut that contains exactly the
 #'   edges that go from \eqn{X} to \eqn{V-X}.}
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
-#' @seealso [st_min_cuts()] to list all minimum cuts.
 #' @references JS Provan and DR Shier: A Paradigm for listing (s,t)-cuts in
 #' graphs, *Algorithmica* 15, 351--372, 1996.
 #' @keywords graphs
@@ -464,7 +667,6 @@ st_cuts <- all_st_cuts_impl
 #'
 #' An \eqn{(s,t)}-cut is minimum if it is of the smallest possible size.
 #'
-#' @aliases st_min_cuts stMincuts
 #' @param graph The input graph. It must be directed.
 #' @param source The id of the source vertex.
 #' @param target The id of the target vertex.
@@ -482,7 +684,6 @@ st_cuts <- all_st_cuts_impl
 #'   generates the cut that contains exactly the edges that go from \eqn{X} to
 #'   \eqn{V-X}.}
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
-#' @seealso [st_cuts()], [min_separators()]
 #' @references JS Provan and DR Shier: A Paradigm for listing (s,t)-cuts in
 #' graphs, *Algorithmica* 15, 351--372, 1996.
 #' @keywords graphs
@@ -518,7 +719,6 @@ st_min_cuts <- all_st_mincuts_impl
 #' This function implements the Lengauer-Tarjan algorithm to construct the
 #' dominator tree of a directed graph. For details see the reference below.
 #'
-#' @aliases dominator.tree dominator_tree
 #' @param graph A directed graph. If it is not a flowgraph, and it contains
 #'   some vertices not reachable from the root vertex, then these vertices will
 #'   be collected and returned as part of the result.
@@ -555,10 +755,8 @@ st_min_cuts <- all_st_mincuts_impl
 #' @export
 dominator_tree <- function(graph, root, mode = c("out", "in", "all", "total")) {
   # Argument checks
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
-  root <- as.igraph.vs(graph, root)
+ ensure_igraph(graph)
+  root <- as_igraph_vs(graph, root)
   if (length(root) == 0) {
     stop("No vertex was specified")
   }
@@ -595,7 +793,6 @@ dominator_tree <- function(graph, root, mode = c("out", "in", "all", "total")) {
 #' A \eqn{(s,t)} vertex separator is minimal if none of its subsets is an
 #' \eqn{(s,t)} vertex separator.
 #'
-#' @aliases minimal.st.separators min_st_separators
 #' @param graph The input graph. It may be directed, but edge directions are
 #'   ignored.
 #' @return A list of numeric vectors. Each vector contains a vertex set
@@ -634,7 +831,6 @@ min_st_separators <- all_minimal_st_separators_impl
 #' the flow is the incoming flow of the `target` vertex. The maximum flow
 #' is the flow of maximum value.
 #'
-#' @aliases graph.maxflow
 #' @param graph The input graph.
 #' @param source The id of the source vertex.
 #' @param target The id of the target vertex (sometimes also called sink).
@@ -666,9 +862,6 @@ min_st_separators <- all_minimal_st_separators_impl
 #'     because of the gap heuristics and `nobfs` is the number of
 #'     times a global breadth-first-search update was performed to assign
 #'     better height (=distance) values to the vertices.}
-#' @seealso [min_cut()] for minimum cut calculations,
-#'   [distances()], [edge_connectivity()],
-#'   [vertex_connectivity()]
 #' @references A. V. Goldberg and R. E. Tarjan: A New Approach to the Maximum
 #' Flow Problem *Journal of the ACM* 35:921-940, 1988.
 #' @examples
@@ -693,14 +886,12 @@ max_flow <- maxflow_impl
 #' In the special case of a fully connected graph with \eqn{n} vertices, each
 #' set of \eqn{n-1} vertices is considered to be a vertex separator.
 #'
-#' @aliases is.separator
 #' @param graph The input graph. It may be directed, but edge directions are
 #'   ignored.
 #' @param candidate A numeric vector giving the vertex ids of the candidate
 #'   separator.
 #' @return A logical scalar, whether the supplied vertex set is a (minimal)
 #'   vertex separator or not.
-#' @seealso [is_min_separator()], [min_separators()]
 #'   lists all vertex separator of minimum size.
 #' @family flow
 #' @export
@@ -718,15 +909,12 @@ is_separator <- is_separator_impl
 #' In the special case of a fully connected graph with \eqn{n} vertices, each
 #' set of \eqn{n-1} vertices is considered to be a vertex separator.
 #'
-#' @aliases is.minimal.separator
 #' @param graph The input graph. It may be directed, but edge directions are
 #'   ignored.
 #' @param candidate A numeric vector giving the vertex ids of the candidate
 #'   separator.
 #' @return A logical scalar, whether the supplied vertex set is a (minimal)
 #'   vertex separator or not.
-#' @seealso [min_separators()] lists all vertex separator of minimum
-#' size.
 #' @examples
 #' # The graph from the Moody-White paper
 #' mw <- graph_from_literal(
@@ -773,12 +961,10 @@ is_min_separator <- is_minimal_separator_impl
 #' In the special case of a fully connected input graph with \eqn{n} vertices,
 #' all subsets of size \eqn{n-1} are listed as the result.
 #'
-#' @aliases minimum.size.separators
 #' @param graph The input graph. It may be directed, but edge directions are
 #'   ignored.
 #' @return A list of numeric vectors. Each numeric vector is a vertex
 #'   separator.
-#' @seealso [is.separator()]
 #' @references Arkady Kanevsky: Finding all minimum-size separating vertex sets
 #' in a graph. *Networks* 23 533--541, 1993.
 #'
@@ -792,7 +978,7 @@ is_min_separator <- is_minimal_separator_impl
 #' @export
 #' @examples
 #' # The graph from the Moody-White paper
-#' mw <- graph.formula(
+#' mw <- graph_from_literal(
 #'   1 - 2:3:4:5:6, 2 - 3:4:5:7, 3 - 4:6:7, 4 - 5:6:7,
 #'   5 - 6:7:21, 6 - 7, 7 - 8:11:14:19, 8 - 9:11:14, 9 - 10,
 #'   10 - 12:13, 11 - 12:14, 12 - 16, 13 - 16, 14 - 15, 15 - 16,
@@ -801,11 +987,11 @@ is_min_separator <- is_minimal_separator_impl
 #' )
 #'
 #' # Cohesive subgraphs
-#' mw1 <- induced.subgraph(mw, as.character(c(1:7, 17:23)))
-#' mw2 <- induced.subgraph(mw, as.character(7:16))
-#' mw3 <- induced.subgraph(mw, as.character(17:23))
-#' mw4 <- induced.subgraph(mw, as.character(c(7, 8, 11, 14)))
-#' mw5 <- induced.subgraph(mw, as.character(1:7))
+#' mw1 <- induced_subgraph(mw, as.character(c(1:7, 17:23)))
+#' mw2 <- induced_subgraph(mw, as.character(7:16))
+#' mw3 <- induced_subgraph(mw, as.character(17:23))
+#' mw4 <- induced_subgraph(mw, as.character(c(7, 8, 11, 14)))
+#' mw5 <- induced_subgraph(mw, as.character(1:7))
 #'
 #' min_separators(mw)
 #' min_separators(mw1)
@@ -815,7 +1001,7 @@ is_min_separator <- is_minimal_separator_impl
 #' min_separators(mw5)
 #'
 #' # Another example, the science camp network
-#' camp <- graph.formula(
+#' camp <- graph_from_literal(
 #'   Harry:Steve:Don:Bert - Harry:Steve:Don:Bert,
 #'   Pam:Brazey:Carol:Pat - Pam:Brazey:Carol:Pat,
 #'   Holly - Carol:Pat:Pam:Jennie:Bill,
