@@ -1,3 +1,48 @@
+
+#' Shortest (directed or undirected) paths between vertices
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `path.length.hist()` was renamed to `distance_table()` to create a more
+#' consistent API.
+#' @inheritParams distance_table
+#' @keywords internal
+#' @export
+path.length.hist <- function(graph, directed = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "path.length.hist()", "distance_table()")
+  distance_table(graph = graph, directed = directed)
+} # nocov end
+
+#' Maximum cardinality search
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `maximum.cardinality.search()` was renamed to `max_cardinality()` to create a more
+#' consistent API.
+#' @inheritParams max_cardinality
+#' @keywords internal
+#' @export
+maximum.cardinality.search <- function(graph) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "maximum.cardinality.search()", "max_cardinality()")
+  max_cardinality(graph = graph)
+} # nocov end
+
+#' Directed acyclic graphs
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `is.dag()` was renamed to `is_dag()` to create a more
+#' consistent API.
+#' @inheritParams is_dag
+#' @keywords internal
+#' @export
+is.dag <- function(graph) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "is.dag()", "is_dag()")
+  is_dag(graph = graph)
+} # nocov end
 ## -----------------------------------------------------------------------
 ##
 ##   IGraph R package
@@ -74,7 +119,7 @@ all_simple_paths <- function(graph, from, to = V(graph),
   ## Function call
   res <- .Call(
     R_igraph_get_all_simple_paths, graph, from - 1, to - 1,
-    as.integer(cutoff), mode
+    as.numeric(cutoff), mode
   )
   res <- get.all.simple.paths.pp(res)
 
@@ -93,7 +138,6 @@ all_simple_paths <- function(graph, from, to = V(graph),
 #' `is_dag()` checks whether there is a directed cycle in the graph. If not,
 #' the graph is a DAG.
 #'
-#' @aliases is.dag is_dag
 #' @param graph The input graph. It may be undirected, in which case
 #'   `FALSE` is reported.
 #' @return A logical vector of length one.
@@ -111,6 +155,27 @@ all_simple_paths <- function(graph, from, to = V(graph),
 #' @export
 is_dag <- is_dag_impl
 
+#' Acyclic graphs
+#'
+#' This function tests whether the given graph is free of cycles.
+#'
+#' This function looks for directed cycles in directed graphs and undirected
+#' cycles in undirected graphs.
+#'
+#' @param graph The input graph.
+#' @return A logical vector of length one.
+#' @keywords graphs
+#' @examples
+#'
+#' g <- make_graph(c(1,2, 1,3, 2,4, 3,4), directed = TRUE)
+#' is_acyclic(g)
+#' is_acyclic(as.undirected(g))
+#' @seealso [is_forest()] and [is_dag()] for functions specific to undirected
+#' and directed graphs.
+#' @family cycles
+#' @family structural.properties
+#' @export
+is_acyclic <- is_acyclic_impl
 
 #' Maximum cardinality search
 #'
@@ -124,7 +189,7 @@ is_dag <- is_dag_impl
 #' The algorithm provides a simple basis for deciding whether a graph is
 #' chordal, see References below, and also [is_chordal()].
 #'
-#' @aliases maximum.cardinality.search max_cardinality
+#' @aliases max_cardinality
 #' @param graph The input graph. It may be directed, but edge directions are
 #'   ignored, as the algorithm is defined for undirected graphs.
 #' @return A list with two components: \item{alpha}{Numeric vector. The
@@ -219,7 +284,7 @@ eccentricity <- eccentricity_impl
 #'   argument is ignored for undirected graphs.
 #' @return A numeric scalar, the radius of the graph.
 #' @seealso [eccentricity()] for the underlying
-#'   calculations, code{[distances]} for general shortest path
+#'   calculations, [distances] for general shortest path
 #'   calculations.
 #' @references Harary, F. Graph Theory. Reading, MA: Addison-Wesley, p. 35,
 #' 1994.
@@ -234,6 +299,5 @@ radius <- radius_impl
 #' @rdname distances
 #' @param directed Whether to consider directed paths in directed graphs,
 #'   this argument is ignored for undirected graphs.
-#' @family paths
 #' @export
 distance_table <- path_length_hist_impl
