@@ -3,7 +3,7 @@ test_that("is_bipartite works", {
   g <- graph_from_biadjacency_matrix(I)
   expect_true(bipartite_mapping(g)$res)
 
-  set.seed(42)
+  withr::local_seed(42)
   I <- matrix(sample(0:1, 35, replace = TRUE, prob = c(3, 1)), ncol = 5)
   g <- graph_from_biadjacency_matrix(I)
   expect_that(
